@@ -3,7 +3,7 @@ package Sah::Schema::cpan::pause_id;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-CPAN'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use strict;
 use Regexp::Pattern::CPAN;
@@ -15,7 +15,7 @@ our $schema = ["str", {
     'x.completion'=>['lcpan_authorid'],
     examples => [
         {value=>'', valid=>0},
-        {value=>'perlancar', valid=>1, res=>'PERLANCAR'},
+        {value=>'perlancar', valid=>1, validated_value=>'PERLANCAR'},
         {value=>'perlancar2', valid=>0, summary=>'Too long'},
     ],
 }, {}];
@@ -36,7 +36,7 @@ Sah::Schema::cpan::pause_id - PAUSE author ID
 
 =head1 VERSION
 
-This document describes version 0.008 of Sah::Schema::cpan::pause_id (from Perl distribution Sah-Schemas-CPAN), released on 2020-03-04.
+This document describes version 0.009 of Sah::Schema::cpan::pause_id (from Perl distribution Sah-Schemas-CPAN), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,7 @@ Sample data:
 
  undef  # INVALID
 
- undef  # valid, becomes "PERLANCAR"
+ undef  # valid
 
  undef  # INVALID (Too long)
 
